@@ -77,11 +77,15 @@ class HopthruClient:
         response = self.session.get(url, headers=self.headers)
         response.raise_for_status()
         interval = response.json()
-        return (
-            APCExtractionInterval.MONTHLY
-            if interval == "Monthly"
-            else APCExtractionInterval.WEEKLY
-        )
+
+        if interval == "Monthly":
+            return APCExtractionInterval.MONTHLY
+        elif interval == "Weekly":
+            return APCExtractionInterval.WEEKLY
+        elif interval == "Daily":
+            return APCExtractionInterval.DAILY
+        else:
+            raise ValueError(f"Unexpected interval value: {interval}")
 
     def get_desired_apc_data_dates(self) -> List[UploadDateDict]:
         """
