@@ -74,6 +74,25 @@ def test_get_apc_data_extraction_interval_monthly():
     assert client.get_apc_data_extraction_interval() == APCExtractionInterval.MONTHLY
 
 
+@httpretty.activate
+def test_get_apc_data_extraction_interval_daily():
+    url = "https://api.hopthru.com/data/interval"
+
+    httpretty.register_uri(
+        httpretty.GET,
+        url,
+        responses=[
+            httpretty.Response(
+                body=json.dumps("Daily"),
+                status=200,
+            ),
+        ],
+    )
+    client = HopthruClient(ApiKeyAuth(api_key="api-key"))
+
+    assert client.get_apc_data_extraction_interval() == APCExtractionInterval.DAILY
+
+
 @httpretty.activate
 def test_get_desired_apc_data_dates():
     url = "https://api.hopthru.com/data/upload_dates"
